@@ -270,7 +270,11 @@ static unsigned long long	gclast;	// last garbage collection (jiffies)
 
 static struct task_struct	*knetatop_task;
 
-static struct timespec	boottime;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 6, 0)
+static struct timespec64	boottime;
+#else
+static struct timespec		boottime;
+#endif
 
 /*
 ** function prototypes
@@ -346,6 +350,14 @@ static struct nf_sockopt_ops sockopts = {
         .owner          = THIS_MODULE,
 };
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 6, 0)
+static struct proc_ops netatop_proc_fops = {
+	.proc_open	= netatop_open,
+	.proc_read	= seq_read,
+	.proc_lseek	= seq_lseek,
+	.proc_release	= single_release,
+};
+#else
 static struct file_operations netatop_proc_fops = {
 	.open           = netatop_open,
 	.read	        = seq_read,
@@ -353,6 +365,7 @@ static struct file_operations netatop_proc_fops = {
 	.release	= single_release,
 	.owner          = THIS_MODULE,
 };
+#endif
 
 
 /*
@@ -965,7 +978,11 @@ get_taskinfo(pid_t id, char type)
 	tip->id    	= id;
 	tip->type    	= type;
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 17, 0)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 5, 0)
+	tip->btime	= div_u64((current->start_boottime +
+				(boottime.tv_sec * NSEC_PER_SEC +
+					boottime.tv_sec)), NSEC_PER_SEC);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(3, 17, 0)
 	tip->btime	= div_u64((current->real_start_time +
 				(boottime.tv_sec * NSEC_PER_SEC +
 					boottime.tv_sec)), NSEC_PER_SEC);
@@ -1599,8 +1616,8 @@ getsockopt(struct sock *sk, int cmd, void __user *user, int *len)
 		return 0;
 
  	   case NETATOP_GETCNT_TGID:
-		tasktype = 'g';
-
+		tasktype = 'g';		
+		// fall through
  	   case NETATOP_GETCNT_PID:
 		if (*len < sizeof(pid_t))
 			return -EINVAL;
@@ -1741,7 +1758,11 @@ init_module()
 		spin_lock_init(&shash[i].lock);
 	}
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 6, 0)
+	getboottime64(&boottime);
+#else
 	getboottime(&boottime);
+#endif
 
 	/*
 	** register getsockopt for user space communication
